@@ -436,9 +436,14 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
                                 "beta": np.nan}
             elif rt == libinference.rec_type.discrete_binomial:
                 if rec_params[i] != "microcanonical":
-                    defaults = {"N": self.rec[i].fa.max(),
-                                "alpha": 1,
-                                "beta": 1}
+                    if "N" in rec_params[i] and len(rec_params[i]) == 1:
+                        defaults = {"N" : rec_params[i]["N"],
+                                    "alpha": np.nan,
+                                    "beta": np.nan}
+                    else:
+                        defaults = {"N": self.rec[i].fa.max(),
+                                    "alpha": 1,
+                                    "beta": 1}
                 else:
                     defaults = {"N": self.rec[i].fa.max(),
                                 "alpha": np.nan,
@@ -1272,6 +1277,20 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
 
         return L
 
+    def modify_edge_dS(self, u, v, dm, entropy_args={}):
+        """Computes the difference in the description length if edge :math:`(u,
+        v)` would have its multiplicity changed by an integer difference ``dm``,
+        taking into account the ``entropy_args`` parameters as described in
+        :meth:`~BlockState.entropy`.
+        """
+        ea = self._get_entropy_args(dict(self._entropy_args, **entropy_args))
+        return self._state.modify_edge_dS(u, v, dm, ea)
+
+    def modify_edge(self, u, v, dm):
+        """Changes the multiplicity of edge ;math:`(u, v)` by a integer
+        difference ``dm``."""
+        return self._state.modify_edge(u, v, dm)
+
     def _clear_egroups(self):
         self._state.clear_egroups()
 
@@ -1338,7 +1357,9 @@ class BlockState(MCMCState, MultiflipMCMCState, MultilevelMCMCState,
 
 
     def collect_edge_marginals(self, p=None, update=1):
-        r"""Collect the edge marginal histogram, which counts the number of times
+        r
+
+        """Collect the edge marginal histogram, which counts the number of times
         the endpoints of each node have been assigned to a given block pair.
 
         This should be called multiple times, e.g. after repeated runs of the
@@ -1658,7 +1679,7 @@ def bethe_entropy(g, p):
 
     .. math::
 
-        H = -\sum_{ij}A_{ij}\sum_{rs}\pi_{ij}(r,s)\ln\pi_{ij}(r,s) - \sum_i(1-k_i)\sum_r\pi_i(r)\ln\pi_i(r),
+        H = -\sum_{i<j}A_{ij}\sum_{rs}\pi_{ij}(r,s)\ln\pi_{ij}(r,s) - \sum_i(1-k_i)\sum_r\pi_i(r)\ln\pi_i(r),
 
     where :math:`\pi_{ij}(r,s)` is the marginal probability that vertices
     :math:`i` and :math:`j` belong to blocks :math:`r` and :math:`s`,
